# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetReleaseLinkResult',
    'AwaitableGetReleaseLinkResult',
    'get_release_link',
    'get_release_link_output',
]

@pulumi.output_type
class GetReleaseLinkResult:
    """
    A collection of values returned by getReleaseLink.
    """
    def __init__(__self__, direct_asset_url=None, external=None, filepath=None, id=None, link_id=None, link_type=None, name=None, project=None, tag_name=None, url=None):
        if direct_asset_url and not isinstance(direct_asset_url, str):
            raise TypeError("Expected argument 'direct_asset_url' to be a str")
        pulumi.set(__self__, "direct_asset_url", direct_asset_url)
        if external and not isinstance(external, bool):
            raise TypeError("Expected argument 'external' to be a bool")
        pulumi.set(__self__, "external", external)
        if filepath and not isinstance(filepath, str):
            raise TypeError("Expected argument 'filepath' to be a str")
        pulumi.set(__self__, "filepath", filepath)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if link_id and not isinstance(link_id, int):
            raise TypeError("Expected argument 'link_id' to be a int")
        pulumi.set(__self__, "link_id", link_id)
        if link_type and not isinstance(link_type, str):
            raise TypeError("Expected argument 'link_type' to be a str")
        pulumi.set(__self__, "link_type", link_type)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if tag_name and not isinstance(tag_name, str):
            raise TypeError("Expected argument 'tag_name' to be a str")
        pulumi.set(__self__, "tag_name", tag_name)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="directAssetUrl")
    def direct_asset_url(self) -> str:
        """
        Full path for a [Direct Asset link](https://docs.gitlab.com/ee/user/project/releases/index.html#permanent-links-to-release-assets).
        """
        return pulumi.get(self, "direct_asset_url")

    @property
    @pulumi.getter
    def external(self) -> bool:
        """
        External or internal link.
        """
        return pulumi.get(self, "external")

    @property
    @pulumi.getter
    def filepath(self) -> str:
        """
        Relative path for a [Direct Asset link](https://docs.gitlab.com/ee/user/project/releases/index.html#permanent-links-to-release-assets).
        """
        return pulumi.get(self, "filepath")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="linkId")
    def link_id(self) -> int:
        """
        The ID of the link.
        """
        return pulumi.get(self, "link_id")

    @property
    @pulumi.getter(name="linkType")
    def link_type(self) -> str:
        """
        The type of the link. Valid values are `other`, `runbook`, `image`, `package`. Defaults to other.
        """
        return pulumi.get(self, "link_type")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the link. Link names must be unique within the release.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID or [URL-encoded path of the project](https://docs.gitlab.com/ee/api/index.html#namespaced-path-encoding).
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="tagName")
    def tag_name(self) -> str:
        """
        The tag associated with the Release.
        """
        return pulumi.get(self, "tag_name")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        The URL of the link. Link URLs must be unique within the release.
        """
        return pulumi.get(self, "url")


class AwaitableGetReleaseLinkResult(GetReleaseLinkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReleaseLinkResult(
            direct_asset_url=self.direct_asset_url,
            external=self.external,
            filepath=self.filepath,
            id=self.id,
            link_id=self.link_id,
            link_type=self.link_type,
            name=self.name,
            project=self.project,
            tag_name=self.tag_name,
            url=self.url)


def get_release_link(link_id: Optional[int] = None,
                     project: Optional[str] = None,
                     tag_name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReleaseLinkResult:
    """
    The `ReleaseLink` data source allows get details of a release link.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/releases/links.html)


    :param int link_id: The ID of the link.
    :param str project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/ee/api/index.html#namespaced-path-encoding).
    :param str tag_name: The tag associated with the Release.
    """
    __args__ = dict()
    __args__['linkId'] = link_id
    __args__['project'] = project
    __args__['tagName'] = tag_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getReleaseLink:getReleaseLink', __args__, opts=opts, typ=GetReleaseLinkResult).value

    return AwaitableGetReleaseLinkResult(
        direct_asset_url=pulumi.get(__ret__, 'direct_asset_url'),
        external=pulumi.get(__ret__, 'external'),
        filepath=pulumi.get(__ret__, 'filepath'),
        id=pulumi.get(__ret__, 'id'),
        link_id=pulumi.get(__ret__, 'link_id'),
        link_type=pulumi.get(__ret__, 'link_type'),
        name=pulumi.get(__ret__, 'name'),
        project=pulumi.get(__ret__, 'project'),
        tag_name=pulumi.get(__ret__, 'tag_name'),
        url=pulumi.get(__ret__, 'url'))


@_utilities.lift_output_func(get_release_link)
def get_release_link_output(link_id: Optional[pulumi.Input[int]] = None,
                            project: Optional[pulumi.Input[str]] = None,
                            tag_name: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetReleaseLinkResult]:
    """
    The `ReleaseLink` data source allows get details of a release link.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/releases/links.html)


    :param int link_id: The ID of the link.
    :param str project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/ee/api/index.html#namespaced-path-encoding).
    :param str tag_name: The tag associated with the Release.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('gitlab')


class _ExportableConfig(types.ModuleType):
    @property
    def base_url(self) -> Optional[str]:
        """
        This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab
        Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from
        the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
        """
        return __config__.get('baseUrl')

    @property
    def cacert_file(self) -> Optional[str]:
        """
        This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab
        CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
        """
        return __config__.get('cacertFile')

    @property
    def client_cert(self) -> Optional[str]:
        """
        File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        """
        return __config__.get('clientCert')

    @property
    def client_key(self) -> Optional[str]:
        """
        File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when
        `client_cert` is set.
        """
        return __config__.get('clientKey')

    @property
    def early_auth_check(self) -> Optional[bool]:
        return __config__.get_bool('earlyAuthCheck')

    @property
    def insecure(self) -> Optional[bool]:
        """
        When set to true this disables SSL verification of the connection to the GitLab instance.
        """
        return __config__.get_bool('insecure')

    @property
    def token(self) -> Optional[str]:
        """
        The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is
        used in this provider for authentication (using Bearer authorization token). See
        https://docs.gitlab.com/ee/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment
        variable.
        """
        return __config__.get('token')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProjectLabelArgs', 'ProjectLabel']

@pulumi.input_type
class ProjectLabelArgs:
    def __init__(__self__, *,
                 color: pulumi.Input[str],
                 project: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProjectLabel resource.
        :param pulumi.Input[str] color: The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        :param pulumi.Input[str] project: The name or id of the project to add the label to.
        :param pulumi.Input[str] description: The description of the label.
        :param pulumi.Input[str] name: The name of the label.
        """
        pulumi.set(__self__, "color", color)
        pulumi.set(__self__, "project", project)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def color(self) -> pulumi.Input[str]:
        """
        The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: pulumi.Input[str]):
        pulumi.set(self, "color", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The name or id of the project to add the label to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the label.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the label.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ProjectLabelState:
    def __init__(__self__, *,
                 color: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 label_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectLabel resources.
        :param pulumi.Input[str] color: The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        :param pulumi.Input[str] description: The description of the label.
        :param pulumi.Input[int] label_id: The id of the project label.
        :param pulumi.Input[str] name: The name of the label.
        :param pulumi.Input[str] project: The name or id of the project to add the label to.
        """
        if color is not None:
            pulumi.set(__self__, "color", color)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if label_id is not None:
            pulumi.set(__self__, "label_id", label_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[str]]:
        """
        The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "color", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the label.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="labelId")
    def label_id(self) -> Optional[pulumi.Input[int]]:
        """
        The id of the project label.
        """
        return pulumi.get(self, "label_id")

    @label_id.setter
    def label_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "label_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the label.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The name or id of the project to add the label to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class ProjectLabel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 color: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `ProjectLabel` resource allows to manage the lifecycle of a project label.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/labels.html#project-labels)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        fixme = gitlab.ProjectLabel("fixme",
            project="example",
            name="fixme",
            description="issue with failing tests",
            color="#ffcc00")
        # Scoped label
        devops_create = gitlab.ProjectLabel("devops_create",
            project=example["id"],
            name="devops::create",
            description="issue for creating infrastructure resources",
            color="#ffa500")
        ```

        ## Import

        Gitlab Project labels can be imported using an id made up of `{project_id}:{group_label_id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectLabel:ProjectLabel example 12345:fixme
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] color: The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        :param pulumi.Input[str] description: The description of the label.
        :param pulumi.Input[str] name: The name of the label.
        :param pulumi.Input[str] project: The name or id of the project to add the label to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectLabelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectLabel` resource allows to manage the lifecycle of a project label.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/labels.html#project-labels)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        fixme = gitlab.ProjectLabel("fixme",
            project="example",
            name="fixme",
            description="issue with failing tests",
            color="#ffcc00")
        # Scoped label
        devops_create = gitlab.ProjectLabel("devops_create",
            project=example["id"],
            name="devops::create",
            description="issue for creating infrastructure resources",
            color="#ffa500")
        ```

        ## Import

        Gitlab Project labels can be imported using an id made up of `{project_id}:{group_label_id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectLabel:ProjectLabel example 12345:fixme
        ```

        :param str resource_name: The name of the resource.
        :param ProjectLabelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectLabelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 color: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectLabelArgs.__new__(ProjectLabelArgs)

            if color is None and not opts.urn:
                raise TypeError("Missing required property 'color'")
            __props__.__dict__["color"] = color
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["label_id"] = None
        super(ProjectLabel, __self__).__init__(
            'gitlab:index/projectLabel:ProjectLabel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            color: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            label_id: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'ProjectLabel':
        """
        Get an existing ProjectLabel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] color: The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        :param pulumi.Input[str] description: The description of the label.
        :param pulumi.Input[int] label_id: The id of the project label.
        :param pulumi.Input[str] name: The name of the label.
        :param pulumi.Input[str] project: The name or id of the project to add the label to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectLabelState.__new__(_ProjectLabelState)

        __props__.__dict__["color"] = color
        __props__.__dict__["description"] = description
        __props__.__dict__["label_id"] = label_id
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        return ProjectLabel(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def color(self) -> pulumi.Output[str]:
        """
        The color of the label given in 6-digit hex notation with leading '#' sign (e.g. #FFAABB) or one of the [CSS color names](https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#Color_keywords).
        """
        return pulumi.get(self, "color")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the label.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="labelId")
    def label_id(self) -> pulumi.Output[int]:
        """
        The id of the project label.
        """
        return pulumi.get(self, "label_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the label.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The name or id of the project to add the label to.
        """
        return pulumi.get(self, "project")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetComplianceFrameworkResult',
    'AwaitableGetComplianceFrameworkResult',
    'get_compliance_framework',
    'get_compliance_framework_output',
]

@pulumi.output_type
class GetComplianceFrameworkResult:
    """
    A collection of values returned by getComplianceFramework.
    """
    def __init__(__self__, color=None, default=None, description=None, framework_id=None, id=None, name=None, namespace_path=None, pipeline_configuration_full_path=None):
        if color and not isinstance(color, str):
            raise TypeError("Expected argument 'color' to be a str")
        pulumi.set(__self__, "color", color)
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if framework_id and not isinstance(framework_id, str):
            raise TypeError("Expected argument 'framework_id' to be a str")
        pulumi.set(__self__, "framework_id", framework_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if namespace_path and not isinstance(namespace_path, str):
            raise TypeError("Expected argument 'namespace_path' to be a str")
        pulumi.set(__self__, "namespace_path", namespace_path)
        if pipeline_configuration_full_path and not isinstance(pipeline_configuration_full_path, str):
            raise TypeError("Expected argument 'pipeline_configuration_full_path' to be a str")
        pulumi.set(__self__, "pipeline_configuration_full_path", pipeline_configuration_full_path)

    @property
    @pulumi.getter
    def color(self) -> str:
        """
        Color representation of the compliance framework in hex format. e.g. #FCA121.
        """
        return pulumi.get(self, "color")

    @property
    @pulumi.getter
    def default(self) -> bool:
        """
        Is the compliance framework the default framework for the group.
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Description for the compliance framework.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="frameworkId")
    def framework_id(self) -> str:
        """
        Globally unique ID of the compliance framework.
        """
        return pulumi.get(self, "framework_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name for the compliance framework.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="namespacePath")
    def namespace_path(self) -> str:
        """
        Full path of the namespace to where the compliance framework is.
        """
        return pulumi.get(self, "namespace_path")

    @property
    @pulumi.getter(name="pipelineConfigurationFullPath")
    def pipeline_configuration_full_path(self) -> str:
        """
        Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa`. Format: `path/file.y[a]ml@group-name/project-name` **Note**: Ultimate license required.
        """
        return pulumi.get(self, "pipeline_configuration_full_path")


class AwaitableGetComplianceFrameworkResult(GetComplianceFrameworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetComplianceFrameworkResult(
            color=self.color,
            default=self.default,
            description=self.description,
            framework_id=self.framework_id,
            id=self.id,
            name=self.name,
            namespace_path=self.namespace_path,
            pipeline_configuration_full_path=self.pipeline_configuration_full_path)


def get_compliance_framework(name: Optional[str] = None,
                             namespace_path: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetComplianceFrameworkResult:
    """
    The `ComplianceFramework` data source allows details of a compliance framework to be retrieved by its name and the namespace it belongs to.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/ee/api/graphql/reference/#querynamespace)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_compliance_framework(namespace_path="top-level-group",
        name="HIPAA")
    ```


    :param str name: Name for the compliance framework.
    :param str namespace_path: Full path of the namespace to where the compliance framework is.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['namespacePath'] = namespace_path
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getComplianceFramework:getComplianceFramework', __args__, opts=opts, typ=GetComplianceFrameworkResult).value

    return AwaitableGetComplianceFrameworkResult(
        color=pulumi.get(__ret__, 'color'),
        default=pulumi.get(__ret__, 'default'),
        description=pulumi.get(__ret__, 'description'),
        framework_id=pulumi.get(__ret__, 'framework_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        namespace_path=pulumi.get(__ret__, 'namespace_path'),
        pipeline_configuration_full_path=pulumi.get(__ret__, 'pipeline_configuration_full_path'))


@_utilities.lift_output_func(get_compliance_framework)
def get_compliance_framework_output(name: Optional[pulumi.Input[str]] = None,
                                    namespace_path: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetComplianceFrameworkResult]:
    """
    The `ComplianceFramework` data source allows details of a compliance framework to be retrieved by its name and the namespace it belongs to.

    **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/ee/api/graphql/reference/#querynamespace)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_compliance_framework(namespace_path="top-level-group",
        name="HIPAA")
    ```


    :param str name: Name for the compliance framework.
    :param str namespace_path: Full path of the namespace to where the compliance framework is.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectIssueArgs', 'ProjectIssue']

@pulumi.input_type
class ProjectIssueArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 title: pulumi.Input[str],
                 assignee_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 confidential: Optional[pulumi.Input[bool]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 delete_on_destroy: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 discussion_locked: Optional[pulumi.Input[bool]] = None,
                 discussion_to_resolve: Optional[pulumi.Input[str]] = None,
                 due_date: Optional[pulumi.Input[str]] = None,
                 epic_issue_id: Optional[pulumi.Input[int]] = None,
                 iid: Optional[pulumi.Input[int]] = None,
                 issue_type: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 merge_request_to_resolve_discussions_of: Optional[pulumi.Input[int]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a ProjectIssue resource.
        :param pulumi.Input[str] project: The name or ID of the project.
        :param pulumi.Input[str] title: The title of the issue.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] assignee_ids: The IDs of the users to assign the issue to.
        :param pulumi.Input[bool] confidential: Set an issue to be confidential.
        :param pulumi.Input[str] created_at: When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        :param pulumi.Input[bool] delete_on_destroy: Whether the issue is deleted instead of closed during destroy.
        :param pulumi.Input[str] description: The description of an issue. Limited to 1,048,576 characters.
        :param pulumi.Input[bool] discussion_locked: Whether the issue is locked for discussions or not.
        :param pulumi.Input[str] discussion_to_resolve: The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        :param pulumi.Input[str] due_date: The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        :param pulumi.Input[int] epic_issue_id: The ID of the epic issue.
        :param pulumi.Input[int] iid: The internal ID of the project's issue.
        :param pulumi.Input[str] issue_type: The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The labels of an issue.
        :param pulumi.Input[int] merge_request_to_resolve_discussions_of: The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        :param pulumi.Input[int] milestone_id: The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        :param pulumi.Input[str] state: The state of the issue. Valid values are: `opened`, `closed`.
        :param pulumi.Input[str] updated_at: When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        :param pulumi.Input[int] weight: The weight of the issue. Valid values are greater than or equal to 0.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "title", title)
        if assignee_ids is not None:
            pulumi.set(__self__, "assignee_ids", assignee_ids)
        if confidential is not None:
            pulumi.set(__self__, "confidential", confidential)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if delete_on_destroy is not None:
            pulumi.set(__self__, "delete_on_destroy", delete_on_destroy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if discussion_locked is not None:
            pulumi.set(__self__, "discussion_locked", discussion_locked)
        if discussion_to_resolve is not None:
            pulumi.set(__self__, "discussion_to_resolve", discussion_to_resolve)
        if due_date is not None:
            pulumi.set(__self__, "due_date", due_date)
        if epic_issue_id is not None:
            pulumi.set(__self__, "epic_issue_id", epic_issue_id)
        if iid is not None:
            pulumi.set(__self__, "iid", iid)
        if issue_type is not None:
            pulumi.set(__self__, "issue_type", issue_type)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if merge_request_to_resolve_discussions_of is not None:
            pulumi.set(__self__, "merge_request_to_resolve_discussions_of", merge_request_to_resolve_discussions_of)
        if milestone_id is not None:
            pulumi.set(__self__, "milestone_id", milestone_id)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The name or ID of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def title(self) -> pulumi.Input[str]:
        """
        The title of the issue.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[str]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="assigneeIds")
    def assignee_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        The IDs of the users to assign the issue to.
        """
        return pulumi.get(self, "assignee_ids")

    @assignee_ids.setter
    def assignee_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "assignee_ids", value)

    @property
    @pulumi.getter
    def confidential(self) -> Optional[pulumi.Input[bool]]:
        """
        Set an issue to be confidential.
        """
        return pulumi.get(self, "confidential")

    @confidential.setter
    def confidential(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "confidential", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="deleteOnDestroy")
    def delete_on_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the issue is deleted instead of closed during destroy.
        """
        return pulumi.get(self, "delete_on_destroy")

    @delete_on_destroy.setter
    def delete_on_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_on_destroy", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of an issue. Limited to 1,048,576 characters.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="discussionLocked")
    def discussion_locked(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the issue is locked for discussions or not.
        """
        return pulumi.get(self, "discussion_locked")

    @discussion_locked.setter
    def discussion_locked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "discussion_locked", value)

    @property
    @pulumi.getter(name="discussionToResolve")
    def discussion_to_resolve(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        """
        return pulumi.get(self, "discussion_to_resolve")

    @discussion_to_resolve.setter
    def discussion_to_resolve(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "discussion_to_resolve", value)

    @property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> Optional[pulumi.Input[str]]:
        """
        The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        """
        return pulumi.get(self, "due_date")

    @due_date.setter
    def due_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "due_date", value)

    @property
    @pulumi.getter(name="epicIssueId")
    def epic_issue_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the epic issue.
        """
        return pulumi.get(self, "epic_issue_id")

    @epic_issue_id.setter
    def epic_issue_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "epic_issue_id", value)

    @property
    @pulumi.getter
    def iid(self) -> Optional[pulumi.Input[int]]:
        """
        The internal ID of the project's issue.
        """
        return pulumi.get(self, "iid")

    @iid.setter
    def iid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "iid", value)

    @property
    @pulumi.getter(name="issueType")
    def issue_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        """
        return pulumi.get(self, "issue_type")

    @issue_type.setter
    def issue_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "issue_type", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The labels of an issue.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter(name="mergeRequestToResolveDiscussionsOf")
    def merge_request_to_resolve_discussions_of(self) -> Optional[pulumi.Input[int]]:
        """
        The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        """
        return pulumi.get(self, "merge_request_to_resolve_discussions_of")

    @merge_request_to_resolve_discussions_of.setter
    def merge_request_to_resolve_discussions_of(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "merge_request_to_resolve_discussions_of", value)

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> Optional[pulumi.Input[int]]:
        """
        The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        """
        return pulumi.get(self, "milestone_id")

    @milestone_id.setter
    def milestone_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "milestone_id", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the issue. Valid values are: `opened`, `closed`.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight of the issue. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class _ProjectIssueState:
    def __init__(__self__, *,
                 assignee_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 author_id: Optional[pulumi.Input[int]] = None,
                 closed_at: Optional[pulumi.Input[str]] = None,
                 closed_by_user_id: Optional[pulumi.Input[int]] = None,
                 confidential: Optional[pulumi.Input[bool]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 delete_on_destroy: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 discussion_locked: Optional[pulumi.Input[bool]] = None,
                 discussion_to_resolve: Optional[pulumi.Input[str]] = None,
                 downvotes: Optional[pulumi.Input[int]] = None,
                 due_date: Optional[pulumi.Input[str]] = None,
                 epic_id: Optional[pulumi.Input[int]] = None,
                 epic_issue_id: Optional[pulumi.Input[int]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 human_time_estimate: Optional[pulumi.Input[str]] = None,
                 human_total_time_spent: Optional[pulumi.Input[str]] = None,
                 iid: Optional[pulumi.Input[int]] = None,
                 issue_id: Optional[pulumi.Input[int]] = None,
                 issue_link_id: Optional[pulumi.Input[int]] = None,
                 issue_type: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 links: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 merge_request_to_resolve_discussions_of: Optional[pulumi.Input[int]] = None,
                 merge_requests_count: Optional[pulumi.Input[int]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 moved_to_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 references: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 subscribed: Optional[pulumi.Input[bool]] = None,
                 task_completion_statuses: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueTaskCompletionStatusArgs']]]] = None,
                 time_estimate: Optional[pulumi.Input[int]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 total_time_spent: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 upvotes: Optional[pulumi.Input[int]] = None,
                 user_notes_count: Optional[pulumi.Input[int]] = None,
                 web_url: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering ProjectIssue resources.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] assignee_ids: The IDs of the users to assign the issue to.
        :param pulumi.Input[int] author_id: The ID of the author of the issue. Use `User` data source to get more information about the user.
        :param pulumi.Input[str] closed_at: When the issue was closed. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        :param pulumi.Input[int] closed_by_user_id: The ID of the user that closed the issue. Use `User` data source to get more information about the user.
        :param pulumi.Input[bool] confidential: Set an issue to be confidential.
        :param pulumi.Input[str] created_at: When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        :param pulumi.Input[bool] delete_on_destroy: Whether the issue is deleted instead of closed during destroy.
        :param pulumi.Input[str] description: The description of an issue. Limited to 1,048,576 characters.
        :param pulumi.Input[bool] discussion_locked: Whether the issue is locked for discussions or not.
        :param pulumi.Input[str] discussion_to_resolve: The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        :param pulumi.Input[int] downvotes: The number of downvotes the issue has received.
        :param pulumi.Input[str] due_date: The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        :param pulumi.Input[int] epic_id: ID of the epic to add the issue to. Valid values are greater than or equal to 0.
        :param pulumi.Input[int] epic_issue_id: The ID of the epic issue.
        :param pulumi.Input[str] external_id: The external ID of the issue.
        :param pulumi.Input[str] human_time_estimate: The human-readable time estimate of the issue.
        :param pulumi.Input[str] human_total_time_spent: The human-readable total time spent of the issue.
        :param pulumi.Input[int] iid: The internal ID of the project's issue.
        :param pulumi.Input[int] issue_id: The instance-wide ID of the issue.
        :param pulumi.Input[int] issue_link_id: The ID of the issue link.
        :param pulumi.Input[str] issue_type: The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The labels of an issue.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] links: The links of the issue.
        :param pulumi.Input[int] merge_request_to_resolve_discussions_of: The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        :param pulumi.Input[int] merge_requests_count: The number of merge requests associated with the issue.
        :param pulumi.Input[int] milestone_id: The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        :param pulumi.Input[int] moved_to_id: The ID of the issue that was moved to.
        :param pulumi.Input[str] project: The name or ID of the project.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] references: The references of the issue.
        :param pulumi.Input[str] state: The state of the issue. Valid values are: `opened`, `closed`.
        :param pulumi.Input[bool] subscribed: Whether the authenticated user is subscribed to the issue or not.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectIssueTaskCompletionStatusArgs']]] task_completion_statuses: The task completion status. It's always a one element list.
        :param pulumi.Input[int] time_estimate: The time estimate of the issue.
        :param pulumi.Input[str] title: The title of the issue.
        :param pulumi.Input[int] total_time_spent: The total time spent of the issue.
        :param pulumi.Input[str] updated_at: When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        :param pulumi.Input[int] upvotes: The number of upvotes the issue has received.
        :param pulumi.Input[int] user_notes_count: The number of user notes on the issue.
        :param pulumi.Input[str] web_url: The web URL of the issue.
        :param pulumi.Input[int] weight: The weight of the issue. Valid values are greater than or equal to 0.
        """
        if assignee_ids is not None:
            pulumi.set(__self__, "assignee_ids", assignee_ids)
        if author_id is not None:
            pulumi.set(__self__, "author_id", author_id)
        if closed_at is not None:
            pulumi.set(__self__, "closed_at", closed_at)
        if closed_by_user_id is not None:
            pulumi.set(__self__, "closed_by_user_id", closed_by_user_id)
        if confidential is not None:
            pulumi.set(__self__, "confidential", confidential)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if delete_on_destroy is not None:
            pulumi.set(__self__, "delete_on_destroy", delete_on_destroy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if discussion_locked is not None:
            pulumi.set(__self__, "discussion_locked", discussion_locked)
        if discussion_to_resolve is not None:
            pulumi.set(__self__, "discussion_to_resolve", discussion_to_resolve)
        if downvotes is not None:
            pulumi.set(__self__, "downvotes", downvotes)
        if due_date is not None:
            pulumi.set(__self__, "due_date", due_date)
        if epic_id is not None:
            pulumi.set(__self__, "epic_id", epic_id)
        if epic_issue_id is not None:
            pulumi.set(__self__, "epic_issue_id", epic_issue_id)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if human_time_estimate is not None:
            pulumi.set(__self__, "human_time_estimate", human_time_estimate)
        if human_total_time_spent is not None:
            pulumi.set(__self__, "human_total_time_spent", human_total_time_spent)
        if iid is not None:
            pulumi.set(__self__, "iid", iid)
        if issue_id is not None:
            pulumi.set(__self__, "issue_id", issue_id)
        if issue_link_id is not None:
            pulumi.set(__self__, "issue_link_id", issue_link_id)
        if issue_type is not None:
            pulumi.set(__self__, "issue_type", issue_type)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if merge_request_to_resolve_discussions_of is not None:
            pulumi.set(__self__, "merge_request_to_resolve_discussions_of", merge_request_to_resolve_discussions_of)
        if merge_requests_count is not None:
            pulumi.set(__self__, "merge_requests_count", merge_requests_count)
        if milestone_id is not None:
            pulumi.set(__self__, "milestone_id", milestone_id)
        if moved_to_id is not None:
            pulumi.set(__self__, "moved_to_id", moved_to_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if references is not None:
            pulumi.set(__self__, "references", references)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if subscribed is not None:
            pulumi.set(__self__, "subscribed", subscribed)
        if task_completion_statuses is not None:
            pulumi.set(__self__, "task_completion_statuses", task_completion_statuses)
        if time_estimate is not None:
            pulumi.set(__self__, "time_estimate", time_estimate)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if total_time_spent is not None:
            pulumi.set(__self__, "total_time_spent", total_time_spent)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if upvotes is not None:
            pulumi.set(__self__, "upvotes", upvotes)
        if user_notes_count is not None:
            pulumi.set(__self__, "user_notes_count", user_notes_count)
        if web_url is not None:
            pulumi.set(__self__, "web_url", web_url)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter(name="assigneeIds")
    def assignee_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        The IDs of the users to assign the issue to.
        """
        return pulumi.get(self, "assignee_ids")

    @assignee_ids.setter
    def assignee_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "assignee_ids", value)

    @property
    @pulumi.getter(name="authorId")
    def author_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the author of the issue. Use `User` data source to get more information about the user.
        """
        return pulumi.get(self, "author_id")

    @author_id.setter
    def author_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "author_id", value)

    @property
    @pulumi.getter(name="closedAt")
    def closed_at(self) -> Optional[pulumi.Input[str]]:
        """
        When the issue was closed. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "closed_at")

    @closed_at.setter
    def closed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "closed_at", value)

    @property
    @pulumi.getter(name="closedByUserId")
    def closed_by_user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the user that closed the issue. Use `User` data source to get more information about the user.
        """
        return pulumi.get(self, "closed_by_user_id")

    @closed_by_user_id.setter
    def closed_by_user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "closed_by_user_id", value)

    @property
    @pulumi.getter
    def confidential(self) -> Optional[pulumi.Input[bool]]:
        """
        Set an issue to be confidential.
        """
        return pulumi.get(self, "confidential")

    @confidential.setter
    def confidential(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "confidential", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="deleteOnDestroy")
    def delete_on_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the issue is deleted instead of closed during destroy.
        """
        return pulumi.get(self, "delete_on_destroy")

    @delete_on_destroy.setter
    def delete_on_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_on_destroy", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of an issue. Limited to 1,048,576 characters.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="discussionLocked")
    def discussion_locked(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the issue is locked for discussions or not.
        """
        return pulumi.get(self, "discussion_locked")

    @discussion_locked.setter
    def discussion_locked(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "discussion_locked", value)

    @property
    @pulumi.getter(name="discussionToResolve")
    def discussion_to_resolve(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        """
        return pulumi.get(self, "discussion_to_resolve")

    @discussion_to_resolve.setter
    def discussion_to_resolve(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "discussion_to_resolve", value)

    @property
    @pulumi.getter
    def downvotes(self) -> Optional[pulumi.Input[int]]:
        """
        The number of downvotes the issue has received.
        """
        return pulumi.get(self, "downvotes")

    @downvotes.setter
    def downvotes(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "downvotes", value)

    @property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> Optional[pulumi.Input[str]]:
        """
        The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        """
        return pulumi.get(self, "due_date")

    @due_date.setter
    def due_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "due_date", value)

    @property
    @pulumi.getter(name="epicId")
    def epic_id(self) -> Optional[pulumi.Input[int]]:
        """
        ID of the epic to add the issue to. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "epic_id")

    @epic_id.setter
    def epic_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "epic_id", value)

    @property
    @pulumi.getter(name="epicIssueId")
    def epic_issue_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the epic issue.
        """
        return pulumi.get(self, "epic_issue_id")

    @epic_issue_id.setter
    def epic_issue_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "epic_issue_id", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        The external ID of the issue.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="humanTimeEstimate")
    def human_time_estimate(self) -> Optional[pulumi.Input[str]]:
        """
        The human-readable time estimate of the issue.
        """
        return pulumi.get(self, "human_time_estimate")

    @human_time_estimate.setter
    def human_time_estimate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "human_time_estimate", value)

    @property
    @pulumi.getter(name="humanTotalTimeSpent")
    def human_total_time_spent(self) -> Optional[pulumi.Input[str]]:
        """
        The human-readable total time spent of the issue.
        """
        return pulumi.get(self, "human_total_time_spent")

    @human_total_time_spent.setter
    def human_total_time_spent(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "human_total_time_spent", value)

    @property
    @pulumi.getter
    def iid(self) -> Optional[pulumi.Input[int]]:
        """
        The internal ID of the project's issue.
        """
        return pulumi.get(self, "iid")

    @iid.setter
    def iid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "iid", value)

    @property
    @pulumi.getter(name="issueId")
    def issue_id(self) -> Optional[pulumi.Input[int]]:
        """
        The instance-wide ID of the issue.
        """
        return pulumi.get(self, "issue_id")

    @issue_id.setter
    def issue_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "issue_id", value)

    @property
    @pulumi.getter(name="issueLinkId")
    def issue_link_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the issue link.
        """
        return pulumi.get(self, "issue_link_id")

    @issue_link_id.setter
    def issue_link_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "issue_link_id", value)

    @property
    @pulumi.getter(name="issueType")
    def issue_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        """
        return pulumi.get(self, "issue_type")

    @issue_type.setter
    def issue_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "issue_type", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The labels of an issue.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The links of the issue.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter(name="mergeRequestToResolveDiscussionsOf")
    def merge_request_to_resolve_discussions_of(self) -> Optional[pulumi.Input[int]]:
        """
        The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        """
        return pulumi.get(self, "merge_request_to_resolve_discussions_of")

    @merge_request_to_resolve_discussions_of.setter
    def merge_request_to_resolve_discussions_of(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "merge_request_to_resolve_discussions_of", value)

    @property
    @pulumi.getter(name="mergeRequestsCount")
    def merge_requests_count(self) -> Optional[pulumi.Input[int]]:
        """
        The number of merge requests associated with the issue.
        """
        return pulumi.get(self, "merge_requests_count")

    @merge_requests_count.setter
    def merge_requests_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "merge_requests_count", value)

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> Optional[pulumi.Input[int]]:
        """
        The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        """
        return pulumi.get(self, "milestone_id")

    @milestone_id.setter
    def milestone_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "milestone_id", value)

    @property
    @pulumi.getter(name="movedToId")
    def moved_to_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the issue that was moved to.
        """
        return pulumi.get(self, "moved_to_id")

    @moved_to_id.setter
    def moved_to_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "moved_to_id", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The name or ID of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def references(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        The references of the issue.
        """
        return pulumi.get(self, "references")

    @references.setter
    def references(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "references", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the issue. Valid values are: `opened`, `closed`.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def subscribed(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the authenticated user is subscribed to the issue or not.
        """
        return pulumi.get(self, "subscribed")

    @subscribed.setter
    def subscribed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "subscribed", value)

    @property
    @pulumi.getter(name="taskCompletionStatuses")
    def task_completion_statuses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueTaskCompletionStatusArgs']]]]:
        """
        The task completion status. It's always a one element list.
        """
        return pulumi.get(self, "task_completion_statuses")

    @task_completion_statuses.setter
    def task_completion_statuses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueTaskCompletionStatusArgs']]]]):
        pulumi.set(self, "task_completion_statuses", value)

    @property
    @pulumi.getter(name="timeEstimate")
    def time_estimate(self) -> Optional[pulumi.Input[int]]:
        """
        The time estimate of the issue.
        """
        return pulumi.get(self, "time_estimate")

    @time_estimate.setter
    def time_estimate(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "time_estimate", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        The title of the issue.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="totalTimeSpent")
    def total_time_spent(self) -> Optional[pulumi.Input[int]]:
        """
        The total time spent of the issue.
        """
        return pulumi.get(self, "total_time_spent")

    @total_time_spent.setter
    def total_time_spent(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "total_time_spent", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def upvotes(self) -> Optional[pulumi.Input[int]]:
        """
        The number of upvotes the issue has received.
        """
        return pulumi.get(self, "upvotes")

    @upvotes.setter
    def upvotes(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "upvotes", value)

    @property
    @pulumi.getter(name="userNotesCount")
    def user_notes_count(self) -> Optional[pulumi.Input[int]]:
        """
        The number of user notes on the issue.
        """
        return pulumi.get(self, "user_notes_count")

    @user_notes_count.setter
    def user_notes_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "user_notes_count", value)

    @property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> Optional[pulumi.Input[str]]:
        """
        The web URL of the issue.
        """
        return pulumi.get(self, "web_url")

    @web_url.setter
    def web_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "web_url", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight of the issue. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


class ProjectIssue(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assignee_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 confidential: Optional[pulumi.Input[bool]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 delete_on_destroy: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 discussion_locked: Optional[pulumi.Input[bool]] = None,
                 discussion_to_resolve: Optional[pulumi.Input[str]] = None,
                 due_date: Optional[pulumi.Input[str]] = None,
                 epic_issue_id: Optional[pulumi.Input[int]] = None,
                 iid: Optional[pulumi.Input[int]] = None,
                 issue_type: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 merge_request_to_resolve_discussions_of: Optional[pulumi.Input[int]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Project("foo",
            name="example project",
            description="Lorem Ipsum",
            visibility_level="public")
        welcome_issue = gitlab.ProjectIssue("welcome_issue",
            project=foo.id,
            title="Welcome!",
            description=foo.name.apply(lambda name: f\"\"\"  Welcome to the {name} project!

        \"\"\"),
            discussion_locked=True)
        pulumi.export("welcomeIssueWebUrl", web_url)
        ```

        ## Import

        You can import this resource with an id made up of `{project-id}:{issue-id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectIssue:ProjectIssue welcome_issue 42:1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] assignee_ids: The IDs of the users to assign the issue to.
        :param pulumi.Input[bool] confidential: Set an issue to be confidential.
        :param pulumi.Input[str] created_at: When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        :param pulumi.Input[bool] delete_on_destroy: Whether the issue is deleted instead of closed during destroy.
        :param pulumi.Input[str] description: The description of an issue. Limited to 1,048,576 characters.
        :param pulumi.Input[bool] discussion_locked: Whether the issue is locked for discussions or not.
        :param pulumi.Input[str] discussion_to_resolve: The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        :param pulumi.Input[str] due_date: The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        :param pulumi.Input[int] epic_issue_id: The ID of the epic issue.
        :param pulumi.Input[int] iid: The internal ID of the project's issue.
        :param pulumi.Input[str] issue_type: The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The labels of an issue.
        :param pulumi.Input[int] merge_request_to_resolve_discussions_of: The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        :param pulumi.Input[int] milestone_id: The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        :param pulumi.Input[str] project: The name or ID of the project.
        :param pulumi.Input[str] state: The state of the issue. Valid values are: `opened`, `closed`.
        :param pulumi.Input[str] title: The title of the issue.
        :param pulumi.Input[str] updated_at: When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        :param pulumi.Input[int] weight: The weight of the issue. Valid values are greater than or equal to 0.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectIssueArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Project("foo",
            name="example project",
            description="Lorem Ipsum",
            visibility_level="public")
        welcome_issue = gitlab.ProjectIssue("welcome_issue",
            project=foo.id,
            title="Welcome!",
            description=foo.name.apply(lambda name: f\"\"\"  Welcome to the {name} project!

        \"\"\"),
            discussion_locked=True)
        pulumi.export("welcomeIssueWebUrl", web_url)
        ```

        ## Import

        You can import this resource with an id made up of `{project-id}:{issue-id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectIssue:ProjectIssue welcome_issue 42:1
        ```

        :param str resource_name: The name of the resource.
        :param ProjectIssueArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectIssueArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assignee_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 confidential: Optional[pulumi.Input[bool]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 delete_on_destroy: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 discussion_locked: Optional[pulumi.Input[bool]] = None,
                 discussion_to_resolve: Optional[pulumi.Input[str]] = None,
                 due_date: Optional[pulumi.Input[str]] = None,
                 epic_issue_id: Optional[pulumi.Input[int]] = None,
                 iid: Optional[pulumi.Input[int]] = None,
                 issue_type: Optional[pulumi.Input[str]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 merge_request_to_resolve_discussions_of: Optional[pulumi.Input[int]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectIssueArgs.__new__(ProjectIssueArgs)

            __props__.__dict__["assignee_ids"] = assignee_ids
            __props__.__dict__["confidential"] = confidential
            __props__.__dict__["created_at"] = created_at
            __props__.__dict__["delete_on_destroy"] = delete_on_destroy
            __props__.__dict__["description"] = description
            __props__.__dict__["discussion_locked"] = discussion_locked
            __props__.__dict__["discussion_to_resolve"] = discussion_to_resolve
            __props__.__dict__["due_date"] = due_date
            __props__.__dict__["epic_issue_id"] = epic_issue_id
            __props__.__dict__["iid"] = iid
            __props__.__dict__["issue_type"] = issue_type
            __props__.__dict__["labels"] = labels
            __props__.__dict__["merge_request_to_resolve_discussions_of"] = merge_request_to_resolve_discussions_of
            __props__.__dict__["milestone_id"] = milestone_id
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["state"] = state
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["updated_at"] = updated_at
            __props__.__dict__["weight"] = weight
            __props__.__dict__["author_id"] = None
            __props__.__dict__["closed_at"] = None
            __props__.__dict__["closed_by_user_id"] = None
            __props__.__dict__["downvotes"] = None
            __props__.__dict__["epic_id"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["human_time_estimate"] = None
            __props__.__dict__["human_total_time_spent"] = None
            __props__.__dict__["issue_id"] = None
            __props__.__dict__["issue_link_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["merge_requests_count"] = None
            __props__.__dict__["moved_to_id"] = None
            __props__.__dict__["references"] = None
            __props__.__dict__["subscribed"] = None
            __props__.__dict__["task_completion_statuses"] = None
            __props__.__dict__["time_estimate"] = None
            __props__.__dict__["total_time_spent"] = None
            __props__.__dict__["upvotes"] = None
            __props__.__dict__["user_notes_count"] = None
            __props__.__dict__["web_url"] = None
        super(ProjectIssue, __self__).__init__(
            'gitlab:index/projectIssue:ProjectIssue',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            assignee_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            author_id: Optional[pulumi.Input[int]] = None,
            closed_at: Optional[pulumi.Input[str]] = None,
            closed_by_user_id: Optional[pulumi.Input[int]] = None,
            confidential: Optional[pulumi.Input[bool]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            delete_on_destroy: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            discussion_locked: Optional[pulumi.Input[bool]] = None,
            discussion_to_resolve: Optional[pulumi.Input[str]] = None,
            downvotes: Optional[pulumi.Input[int]] = None,
            due_date: Optional[pulumi.Input[str]] = None,
            epic_id: Optional[pulumi.Input[int]] = None,
            epic_issue_id: Optional[pulumi.Input[int]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            human_time_estimate: Optional[pulumi.Input[str]] = None,
            human_total_time_spent: Optional[pulumi.Input[str]] = None,
            iid: Optional[pulumi.Input[int]] = None,
            issue_id: Optional[pulumi.Input[int]] = None,
            issue_link_id: Optional[pulumi.Input[int]] = None,
            issue_type: Optional[pulumi.Input[str]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            links: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            merge_request_to_resolve_discussions_of: Optional[pulumi.Input[int]] = None,
            merge_requests_count: Optional[pulumi.Input[int]] = None,
            milestone_id: Optional[pulumi.Input[int]] = None,
            moved_to_id: Optional[pulumi.Input[int]] = None,
            project: Optional[pulumi.Input[str]] = None,
            references: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            state: Optional[pulumi.Input[str]] = None,
            subscribed: Optional[pulumi.Input[bool]] = None,
            task_completion_statuses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectIssueTaskCompletionStatusArgs']]]]] = None,
            time_estimate: Optional[pulumi.Input[int]] = None,
            title: Optional[pulumi.Input[str]] = None,
            total_time_spent: Optional[pulumi.Input[int]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            upvotes: Optional[pulumi.Input[int]] = None,
            user_notes_count: Optional[pulumi.Input[int]] = None,
            web_url: Optional[pulumi.Input[str]] = None,
            weight: Optional[pulumi.Input[int]] = None) -> 'ProjectIssue':
        """
        Get an existing ProjectIssue resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] assignee_ids: The IDs of the users to assign the issue to.
        :param pulumi.Input[int] author_id: The ID of the author of the issue. Use `User` data source to get more information about the user.
        :param pulumi.Input[str] closed_at: When the issue was closed. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        :param pulumi.Input[int] closed_by_user_id: The ID of the user that closed the issue. Use `User` data source to get more information about the user.
        :param pulumi.Input[bool] confidential: Set an issue to be confidential.
        :param pulumi.Input[str] created_at: When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        :param pulumi.Input[bool] delete_on_destroy: Whether the issue is deleted instead of closed during destroy.
        :param pulumi.Input[str] description: The description of an issue. Limited to 1,048,576 characters.
        :param pulumi.Input[bool] discussion_locked: Whether the issue is locked for discussions or not.
        :param pulumi.Input[str] discussion_to_resolve: The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        :param pulumi.Input[int] downvotes: The number of downvotes the issue has received.
        :param pulumi.Input[str] due_date: The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        :param pulumi.Input[int] epic_id: ID of the epic to add the issue to. Valid values are greater than or equal to 0.
        :param pulumi.Input[int] epic_issue_id: The ID of the epic issue.
        :param pulumi.Input[str] external_id: The external ID of the issue.
        :param pulumi.Input[str] human_time_estimate: The human-readable time estimate of the issue.
        :param pulumi.Input[str] human_total_time_spent: The human-readable total time spent of the issue.
        :param pulumi.Input[int] iid: The internal ID of the project's issue.
        :param pulumi.Input[int] issue_id: The instance-wide ID of the issue.
        :param pulumi.Input[int] issue_link_id: The ID of the issue link.
        :param pulumi.Input[str] issue_type: The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The labels of an issue.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] links: The links of the issue.
        :param pulumi.Input[int] merge_request_to_resolve_discussions_of: The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        :param pulumi.Input[int] merge_requests_count: The number of merge requests associated with the issue.
        :param pulumi.Input[int] milestone_id: The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        :param pulumi.Input[int] moved_to_id: The ID of the issue that was moved to.
        :param pulumi.Input[str] project: The name or ID of the project.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] references: The references of the issue.
        :param pulumi.Input[str] state: The state of the issue. Valid values are: `opened`, `closed`.
        :param pulumi.Input[bool] subscribed: Whether the authenticated user is subscribed to the issue or not.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectIssueTaskCompletionStatusArgs']]]] task_completion_statuses: The task completion status. It's always a one element list.
        :param pulumi.Input[int] time_estimate: The time estimate of the issue.
        :param pulumi.Input[str] title: The title of the issue.
        :param pulumi.Input[int] total_time_spent: The total time spent of the issue.
        :param pulumi.Input[str] updated_at: When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        :param pulumi.Input[int] upvotes: The number of upvotes the issue has received.
        :param pulumi.Input[int] user_notes_count: The number of user notes on the issue.
        :param pulumi.Input[str] web_url: The web URL of the issue.
        :param pulumi.Input[int] weight: The weight of the issue. Valid values are greater than or equal to 0.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectIssueState.__new__(_ProjectIssueState)

        __props__.__dict__["assignee_ids"] = assignee_ids
        __props__.__dict__["author_id"] = author_id
        __props__.__dict__["closed_at"] = closed_at
        __props__.__dict__["closed_by_user_id"] = closed_by_user_id
        __props__.__dict__["confidential"] = confidential
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["delete_on_destroy"] = delete_on_destroy
        __props__.__dict__["description"] = description
        __props__.__dict__["discussion_locked"] = discussion_locked
        __props__.__dict__["discussion_to_resolve"] = discussion_to_resolve
        __props__.__dict__["downvotes"] = downvotes
        __props__.__dict__["due_date"] = due_date
        __props__.__dict__["epic_id"] = epic_id
        __props__.__dict__["epic_issue_id"] = epic_issue_id
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["human_time_estimate"] = human_time_estimate
        __props__.__dict__["human_total_time_spent"] = human_total_time_spent
        __props__.__dict__["iid"] = iid
        __props__.__dict__["issue_id"] = issue_id
        __props__.__dict__["issue_link_id"] = issue_link_id
        __props__.__dict__["issue_type"] = issue_type
        __props__.__dict__["labels"] = labels
        __props__.__dict__["links"] = links
        __props__.__dict__["merge_request_to_resolve_discussions_of"] = merge_request_to_resolve_discussions_of
        __props__.__dict__["merge_requests_count"] = merge_requests_count
        __props__.__dict__["milestone_id"] = milestone_id
        __props__.__dict__["moved_to_id"] = moved_to_id
        __props__.__dict__["project"] = project
        __props__.__dict__["references"] = references
        __props__.__dict__["state"] = state
        __props__.__dict__["subscribed"] = subscribed
        __props__.__dict__["task_completion_statuses"] = task_completion_statuses
        __props__.__dict__["time_estimate"] = time_estimate
        __props__.__dict__["title"] = title
        __props__.__dict__["total_time_spent"] = total_time_spent
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["upvotes"] = upvotes
        __props__.__dict__["user_notes_count"] = user_notes_count
        __props__.__dict__["web_url"] = web_url
        __props__.__dict__["weight"] = weight
        return ProjectIssue(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="assigneeIds")
    def assignee_ids(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        The IDs of the users to assign the issue to.
        """
        return pulumi.get(self, "assignee_ids")

    @property
    @pulumi.getter(name="authorId")
    def author_id(self) -> pulumi.Output[int]:
        """
        The ID of the author of the issue. Use `User` data source to get more information about the user.
        """
        return pulumi.get(self, "author_id")

    @property
    @pulumi.getter(name="closedAt")
    def closed_at(self) -> pulumi.Output[str]:
        """
        When the issue was closed. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "closed_at")

    @property
    @pulumi.getter(name="closedByUserId")
    def closed_by_user_id(self) -> pulumi.Output[int]:
        """
        The ID of the user that closed the issue. Use `User` data source to get more information about the user.
        """
        return pulumi.get(self, "closed_by_user_id")

    @property
    @pulumi.getter
    def confidential(self) -> pulumi.Output[Optional[bool]]:
        """
        Set an issue to be confidential.
        """
        return pulumi.get(self, "confidential")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="deleteOnDestroy")
    def delete_on_destroy(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the issue is deleted instead of closed during destroy.
        """
        return pulumi.get(self, "delete_on_destroy")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of an issue. Limited to 1,048,576 characters.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="discussionLocked")
    def discussion_locked(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the issue is locked for discussions or not.
        """
        return pulumi.get(self, "discussion_locked")

    @property
    @pulumi.getter(name="discussionToResolve")
    def discussion_to_resolve(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge*request*to*resolve*discussions_of.
        """
        return pulumi.get(self, "discussion_to_resolve")

    @property
    @pulumi.getter
    def downvotes(self) -> pulumi.Output[int]:
        """
        The number of downvotes the issue has received.
        """
        return pulumi.get(self, "downvotes")

    @property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> pulumi.Output[Optional[str]]:
        """
        The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11.
        """
        return pulumi.get(self, "due_date")

    @property
    @pulumi.getter(name="epicId")
    def epic_id(self) -> pulumi.Output[int]:
        """
        ID of the epic to add the issue to. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "epic_id")

    @property
    @pulumi.getter(name="epicIssueId")
    def epic_issue_id(self) -> pulumi.Output[int]:
        """
        The ID of the epic issue.
        """
        return pulumi.get(self, "epic_issue_id")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        The external ID of the issue.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="humanTimeEstimate")
    def human_time_estimate(self) -> pulumi.Output[str]:
        """
        The human-readable time estimate of the issue.
        """
        return pulumi.get(self, "human_time_estimate")

    @property
    @pulumi.getter(name="humanTotalTimeSpent")
    def human_total_time_spent(self) -> pulumi.Output[str]:
        """
        The human-readable total time spent of the issue.
        """
        return pulumi.get(self, "human_total_time_spent")

    @property
    @pulumi.getter
    def iid(self) -> pulumi.Output[int]:
        """
        The internal ID of the project's issue.
        """
        return pulumi.get(self, "iid")

    @property
    @pulumi.getter(name="issueId")
    def issue_id(self) -> pulumi.Output[int]:
        """
        The instance-wide ID of the issue.
        """
        return pulumi.get(self, "issue_id")

    @property
    @pulumi.getter(name="issueLinkId")
    def issue_link_id(self) -> pulumi.Output[int]:
        """
        The ID of the issue link.
        """
        return pulumi.get(self, "issue_link_id")

    @property
    @pulumi.getter(name="issueType")
    def issue_type(self) -> pulumi.Output[Optional[str]]:
        """
        The type of issue. Valid values are: `issue`, `incident`, `test_case`.
        """
        return pulumi.get(self, "issue_type")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The labels of an issue.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Mapping[str, str]]:
        """
        The links of the issue.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter(name="mergeRequestToResolveDiscussionsOf")
    def merge_request_to_resolve_discussions_of(self) -> pulumi.Output[Optional[int]]:
        """
        The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
        """
        return pulumi.get(self, "merge_request_to_resolve_discussions_of")

    @property
    @pulumi.getter(name="mergeRequestsCount")
    def merge_requests_count(self) -> pulumi.Output[int]:
        """
        The number of merge requests associated with the issue.
        """
        return pulumi.get(self, "merge_requests_count")

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> pulumi.Output[Optional[int]]:
        """
        The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
        """
        return pulumi.get(self, "milestone_id")

    @property
    @pulumi.getter(name="movedToId")
    def moved_to_id(self) -> pulumi.Output[int]:
        """
        The ID of the issue that was moved to.
        """
        return pulumi.get(self, "moved_to_id")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The name or ID of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def references(self) -> pulumi.Output[Mapping[str, str]]:
        """
        The references of the issue.
        """
        return pulumi.get(self, "references")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[Optional[str]]:
        """
        The state of the issue. Valid values are: `opened`, `closed`.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def subscribed(self) -> pulumi.Output[bool]:
        """
        Whether the authenticated user is subscribed to the issue or not.
        """
        return pulumi.get(self, "subscribed")

    @property
    @pulumi.getter(name="taskCompletionStatuses")
    def task_completion_statuses(self) -> pulumi.Output[Sequence['outputs.ProjectIssueTaskCompletionStatus']]:
        """
        The task completion status. It's always a one element list.
        """
        return pulumi.get(self, "task_completion_statuses")

    @property
    @pulumi.getter(name="timeEstimate")
    def time_estimate(self) -> pulumi.Output[int]:
        """
        The time estimate of the issue.
        """
        return pulumi.get(self, "time_estimate")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        The title of the issue.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="totalTimeSpent")
    def total_time_spent(self) -> pulumi.Output[int]:
        """
        The total time spent of the issue.
        """
        return pulumi.get(self, "total_time_spent")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def upvotes(self) -> pulumi.Output[int]:
        """
        The number of upvotes the issue has received.
        """
        return pulumi.get(self, "upvotes")

    @property
    @pulumi.getter(name="userNotesCount")
    def user_notes_count(self) -> pulumi.Output[int]:
        """
        The number of user notes on the issue.
        """
        return pulumi.get(self, "user_notes_count")

    @property
    @pulumi.getter(name="webUrl")
    def web_url(self) -> pulumi.Output[str]:
        """
        The web URL of the issue.
        """
        return pulumi.get(self, "web_url")

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Output[int]:
        """
        The weight of the issue. Valid values are greater than or equal to 0.
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 base_url: Optional[pulumi.Input[str]] = None,
                 cacert_file: Optional[pulumi.Input[str]] = None,
                 client_cert: Optional[pulumi.Input[str]] = None,
                 client_key: Optional[pulumi.Input[str]] = None,
                 early_auth_check: Optional[pulumi.Input[bool]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 token: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[str] base_url: This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab
               Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from
               the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
        :param pulumi.Input[str] cacert_file: This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab
               CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
        :param pulumi.Input[str] client_cert: File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        :param pulumi.Input[str] client_key: File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when
               `client_cert` is set.
        :param pulumi.Input[bool] insecure: When set to true this disables SSL verification of the connection to the GitLab instance.
        :param pulumi.Input[str] token: The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is
               used in this provider for authentication (using Bearer authorization token). See
               https://docs.gitlab.com/ee/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment
               variable.
        """
        if base_url is not None:
            pulumi.set(__self__, "base_url", base_url)
        if cacert_file is not None:
            pulumi.set(__self__, "cacert_file", cacert_file)
        if client_cert is not None:
            pulumi.set(__self__, "client_cert", client_cert)
        if client_key is not None:
            pulumi.set(__self__, "client_key", client_key)
        if early_auth_check is not None:
            pulumi.set(__self__, "early_auth_check", early_auth_check)
        if insecure is not None:
            pulumi.set(__self__, "insecure", insecure)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> Optional[pulumi.Input[str]]:
        """
        This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab
        Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from
        the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
        """
        return pulumi.get(self, "base_url")

    @base_url.setter
    def base_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "base_url", value)

    @property
    @pulumi.getter(name="cacertFile")
    def cacert_file(self) -> Optional[pulumi.Input[str]]:
        """
        This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab
        CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
        """
        return pulumi.get(self, "cacert_file")

    @cacert_file.setter
    def cacert_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cacert_file", value)

    @property
    @pulumi.getter(name="clientCert")
    def client_cert(self) -> Optional[pulumi.Input[str]]:
        """
        File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        """
        return pulumi.get(self, "client_cert")

    @client_cert.setter
    def client_cert(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_cert", value)

    @property
    @pulumi.getter(name="clientKey")
    def client_key(self) -> Optional[pulumi.Input[str]]:
        """
        File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when
        `client_cert` is set.
        """
        return pulumi.get(self, "client_key")

    @client_key.setter
    def client_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_key", value)

    @property
    @pulumi.getter(name="earlyAuthCheck")
    def early_auth_check(self) -> Optional[pulumi.Input[bool]]:
        return pulumi.get(self, "early_auth_check")

    @early_auth_check.setter
    def early_auth_check(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "early_auth_check", value)

    @property
    @pulumi.getter
    def insecure(self) -> Optional[pulumi.Input[bool]]:
        """
        When set to true this disables SSL verification of the connection to the GitLab instance.
        """
        return pulumi.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "insecure", value)

    @property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[str]]:
        """
        The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is
        used in this provider for authentication (using Bearer authorization token). See
        https://docs.gitlab.com/ee/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token", value)


class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_url: Optional[pulumi.Input[str]] = None,
                 cacert_file: Optional[pulumi.Input[str]] = None,
                 client_cert: Optional[pulumi.Input[str]] = None,
                 client_key: Optional[pulumi.Input[str]] = None,
                 early_auth_check: Optional[pulumi.Input[bool]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The provider type for the gitlab package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] base_url: This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab
               Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from
               the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
        :param pulumi.Input[str] cacert_file: This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab
               CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
        :param pulumi.Input[str] client_cert: File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        :param pulumi.Input[str] client_key: File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when
               `client_cert` is set.
        :param pulumi.Input[bool] insecure: When set to true this disables SSL verification of the connection to the GitLab instance.
        :param pulumi.Input[str] token: The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is
               used in this provider for authentication (using Bearer authorization token). See
               https://docs.gitlab.com/ee/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment
               variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the gitlab package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 base_url: Optional[pulumi.Input[str]] = None,
                 cacert_file: Optional[pulumi.Input[str]] = None,
                 client_cert: Optional[pulumi.Input[str]] = None,
                 client_key: Optional[pulumi.Input[str]] = None,
                 early_auth_check: Optional[pulumi.Input[bool]] = None,
                 insecure: Optional[pulumi.Input[bool]] = None,
                 token: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["base_url"] = base_url
            __props__.__dict__["cacert_file"] = cacert_file
            __props__.__dict__["client_cert"] = client_cert
            __props__.__dict__["client_key"] = client_key
            __props__.__dict__["early_auth_check"] = pulumi.Output.from_input(early_auth_check).apply(pulumi.runtime.to_json) if early_auth_check is not None else None
            __props__.__dict__["insecure"] = pulumi.Output.from_input(insecure).apply(pulumi.runtime.to_json) if insecure is not None else None
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'gitlab',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="baseUrl")
    def base_url(self) -> pulumi.Output[Optional[str]]:
        """
        This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab
        Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from
        the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
        """
        return pulumi.get(self, "base_url")

    @property
    @pulumi.getter(name="cacertFile")
    def cacert_file(self) -> pulumi.Output[Optional[str]]:
        """
        This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab
        CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
        """
        return pulumi.get(self, "cacert_file")

    @property
    @pulumi.getter(name="clientCert")
    def client_cert(self) -> pulumi.Output[Optional[str]]:
        """
        File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        """
        return pulumi.get(self, "client_cert")

    @property
    @pulumi.getter(name="clientKey")
    def client_key(self) -> pulumi.Output[Optional[str]]:
        """
        File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when
        `client_cert` is set.
        """
        return pulumi.get(self, "client_key")

    @property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[str]]:
        """
        The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is
        used in this provider for authentication (using Bearer authorization token). See
        https://docs.gitlab.com/ee/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "token")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['IntegrationJenkinsArgs', 'IntegrationJenkins']

@pulumi.input_type
class IntegrationJenkinsArgs:
    def __init__(__self__, *,
                 jenkins_url: pulumi.Input[str],
                 project: pulumi.Input[str],
                 project_name: pulumi.Input[str],
                 enable_ssl_verification: Optional[pulumi.Input[bool]] = None,
                 merge_request_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a IntegrationJenkins resource.
        :param pulumi.Input[str] jenkins_url: Jenkins URL like `http://jenkins.example.com`
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_name: The URL-friendly project name. Example: `my_project_name`.
        :param pulumi.Input[bool] enable_ssl_verification: Enable SSL verification. Defaults to `true` (enabled).
        :param pulumi.Input[bool] merge_request_events: Enable notifications for merge request events.
        :param pulumi.Input[str] password: Password for authentication with the Jenkins server, if authentication is required by the server.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] username: Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        pulumi.set(__self__, "jenkins_url", jenkins_url)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "project_name", project_name)
        if enable_ssl_verification is not None:
            pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if merge_request_events is not None:
            pulumi.set(__self__, "merge_request_events", merge_request_events)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="jenkinsUrl")
    def jenkins_url(self) -> pulumi.Input[str]:
        """
        Jenkins URL like `http://jenkins.example.com`
        """
        return pulumi.get(self, "jenkins_url")

    @jenkins_url.setter
    def jenkins_url(self, value: pulumi.Input[str]):
        pulumi.set(self, "jenkins_url", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[str]:
        """
        The URL-friendly project name. Example: `my_project_name`.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable SSL verification. Defaults to `true` (enabled).
        """
        return pulumi.get(self, "enable_ssl_verification")

    @enable_ssl_verification.setter
    def enable_ssl_verification(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ssl_verification", value)

    @property
    @pulumi.getter(name="mergeRequestEvents")
    def merge_request_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merge request events.
        """
        return pulumi.get(self, "merge_request_events")

    @merge_request_events.setter
    def merge_request_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_request_events", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Password for authentication with the Jenkins server, if authentication is required by the server.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _IntegrationJenkinsState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 enable_ssl_verification: Optional[pulumi.Input[bool]] = None,
                 jenkins_url: Optional[pulumi.Input[str]] = None,
                 merge_request_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IntegrationJenkins resources.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[bool] enable_ssl_verification: Enable SSL verification. Defaults to `true` (enabled).
        :param pulumi.Input[str] jenkins_url: Jenkins URL like `http://jenkins.example.com`
        :param pulumi.Input[bool] merge_request_events: Enable notifications for merge request events.
        :param pulumi.Input[str] password: Password for authentication with the Jenkins server, if authentication is required by the server.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_name: The URL-friendly project name. Example: `my_project_name`.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] username: Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if enable_ssl_verification is not None:
            pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if jenkins_url is not None:
            pulumi.set(__self__, "jenkins_url", jenkins_url)
        if merge_request_events is not None:
            pulumi.set(__self__, "merge_request_events", merge_request_events)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable SSL verification. Defaults to `true` (enabled).
        """
        return pulumi.get(self, "enable_ssl_verification")

    @enable_ssl_verification.setter
    def enable_ssl_verification(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ssl_verification", value)

    @property
    @pulumi.getter(name="jenkinsUrl")
    def jenkins_url(self) -> Optional[pulumi.Input[str]]:
        """
        Jenkins URL like `http://jenkins.example.com`
        """
        return pulumi.get(self, "jenkins_url")

    @jenkins_url.setter
    def jenkins_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jenkins_url", value)

    @property
    @pulumi.getter(name="mergeRequestEvents")
    def merge_request_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for merge request events.
        """
        return pulumi.get(self, "merge_request_events")

    @merge_request_events.setter
    def merge_request_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "merge_request_events", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Password for authentication with the Jenkins server, if authentication is required by the server.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The URL-friendly project name. Example: `my_project_name`.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "push_events", value)

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[bool]]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tag_push_events", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class IntegrationJenkins(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_ssl_verification: Optional[pulumi.Input[bool]] = None,
                 jenkins_url: Optional[pulumi.Input[str]] = None,
                 merge_request_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `IntegrationJenkins` resource allows to manage the lifecycle of a project integration with Jenkins.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/integrations.html#jenkins)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        jenkins = gitlab.IntegrationJenkins("jenkins",
            project=awesome_project.id,
            jenkins_url="http://jenkins.example.com",
            project_name="my_project_name")
        ```

        ## Import

        ```sh
        $ pulumi import gitlab:index/integrationJenkins:IntegrationJenkins You can import a gitlab_integration_jenkins state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/integrationJenkins:IntegrationJenkins jenkins 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_ssl_verification: Enable SSL verification. Defaults to `true` (enabled).
        :param pulumi.Input[str] jenkins_url: Jenkins URL like `http://jenkins.example.com`
        :param pulumi.Input[bool] merge_request_events: Enable notifications for merge request events.
        :param pulumi.Input[str] password: Password for authentication with the Jenkins server, if authentication is required by the server.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_name: The URL-friendly project name. Example: `my_project_name`.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] username: Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationJenkinsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `IntegrationJenkins` resource allows to manage the lifecycle of a project integration with Jenkins.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/integrations.html#jenkins)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        jenkins = gitlab.IntegrationJenkins("jenkins",
            project=awesome_project.id,
            jenkins_url="http://jenkins.example.com",
            project_name="my_project_name")
        ```

        ## Import

        ```sh
        $ pulumi import gitlab:index/integrationJenkins:IntegrationJenkins You can import a gitlab_integration_jenkins state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/integrationJenkins:IntegrationJenkins jenkins 1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationJenkinsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationJenkinsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_ssl_verification: Optional[pulumi.Input[bool]] = None,
                 jenkins_url: Optional[pulumi.Input[str]] = None,
                 merge_request_events: Optional[pulumi.Input[bool]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 push_events: Optional[pulumi.Input[bool]] = None,
                 tag_push_events: Optional[pulumi.Input[bool]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationJenkinsArgs.__new__(IntegrationJenkinsArgs)

            __props__.__dict__["enable_ssl_verification"] = enable_ssl_verification
            if jenkins_url is None and not opts.urn:
                raise TypeError("Missing required property 'jenkins_url'")
            __props__.__dict__["jenkins_url"] = jenkins_url
            __props__.__dict__["merge_request_events"] = merge_request_events
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["push_events"] = push_events
            __props__.__dict__["tag_push_events"] = tag_push_events
            __props__.__dict__["username"] = username
            __props__.__dict__["active"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(IntegrationJenkins, __self__).__init__(
            'gitlab:index/integrationJenkins:IntegrationJenkins',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            enable_ssl_verification: Optional[pulumi.Input[bool]] = None,
            jenkins_url: Optional[pulumi.Input[str]] = None,
            merge_request_events: Optional[pulumi.Input[bool]] = None,
            password: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            push_events: Optional[pulumi.Input[bool]] = None,
            tag_push_events: Optional[pulumi.Input[bool]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'IntegrationJenkins':
        """
        Get an existing IntegrationJenkins resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[bool] enable_ssl_verification: Enable SSL verification. Defaults to `true` (enabled).
        :param pulumi.Input[str] jenkins_url: Jenkins URL like `http://jenkins.example.com`
        :param pulumi.Input[bool] merge_request_events: Enable notifications for merge request events.
        :param pulumi.Input[str] password: Password for authentication with the Jenkins server, if authentication is required by the server.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_name: The URL-friendly project name. Example: `my_project_name`.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] username: Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationJenkinsState.__new__(_IntegrationJenkinsState)

        __props__.__dict__["active"] = active
        __props__.__dict__["enable_ssl_verification"] = enable_ssl_verification
        __props__.__dict__["jenkins_url"] = jenkins_url
        __props__.__dict__["merge_request_events"] = merge_request_events
        __props__.__dict__["password"] = password
        __props__.__dict__["project"] = project
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["push_events"] = push_events
        __props__.__dict__["tag_push_events"] = tag_push_events
        __props__.__dict__["username"] = username
        return IntegrationJenkins(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[bool]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> pulumi.Output[bool]:
        """
        Enable SSL verification. Defaults to `true` (enabled).
        """
        return pulumi.get(self, "enable_ssl_verification")

    @property
    @pulumi.getter(name="jenkinsUrl")
    def jenkins_url(self) -> pulumi.Output[str]:
        """
        Jenkins URL like `http://jenkins.example.com`
        """
        return pulumi.get(self, "jenkins_url")

    @property
    @pulumi.getter(name="mergeRequestEvents")
    def merge_request_events(self) -> pulumi.Output[bool]:
        """
        Enable notifications for merge request events.
        """
        return pulumi.get(self, "merge_request_events")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        Password for authentication with the Jenkins server, if authentication is required by the server.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        The URL-friendly project name. Example: `my_project_name`.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> pulumi.Output[bool]:
        """
        Enable notifications for push events.
        """
        return pulumi.get(self, "push_events")

    @property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> pulumi.Output[bool]:
        """
        Enable notifications for tag push events.
        """
        return pulumi.get(self, "tag_push_events")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[str]]:
        """
        Username for authentication with the Jenkins server, if authentication is required by the server.
        """
        return pulumi.get(self, "username")

